@@ -10,7 +10,7 @@ use SWISH::Prog::Utils;
 
 __PACKAGE__->mk_accessors(qw( db alias_columns schema ));
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 my $XMLer = Search::Tools::XML->new();    # included in Utils
 
@@ -347,6 +347,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
