@@ -15,7 +15,7 @@ __PACKAGE__->mk_accessors(
 
 #use LWP::Debug qw(+);
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 # TODO make these configurable
 my %parser_types = %SWISH::Prog::Utils::ParserTypes;
@@ -479,6 +479,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
