@@ -14,7 +14,7 @@ use overload(
     fallback => 1,
 );
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 our $XMLer = Search::Tools::XML->new;
 
@@ -546,6 +546,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
