@@ -5,7 +5,7 @@ use base qw( SWISH::Prog::Class );
 use Carp;
 use XML::Simple;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 __PACKAGE__->mk_accessors(qw( invindex ));
 __PACKAGE__->mk_ro_accessors(qw( file ));
@@ -95,6 +95,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
