@@ -8,7 +8,7 @@ use SWISH::Prog::Native::InvIndex;
 use SWISH::Prog::Config;
 use Scalar::Util qw( blessed );
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 my $invindex_class = 'SWISH::Prog::Native::InvIndex';
 
@@ -385,6 +385,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
