@@ -9,7 +9,7 @@ use SWISH::Prog::Native::Result;
 
 __PACKAGE__->mk_accessors(qw( swish sao_opts result_class ));
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 =head1 NAME
 
@@ -97,6 +97,10 @@ You can also look for information at:
 
 =over 4
 
+=item * Mailing list
+
+L<http://lists.swish-e.org/listinfo/users>
+
 =item * RT: CPAN's request tracker
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=SWISH-Prog>
